==> antd-2.6.1.jar: META-INF/resources/webjars/antd/2.6.1/lib/upload/interface.d.ts <==
/// <reference types="react" />
import React from 'react';
export declare type UploadFileStatus = 'error' | 'success' | 'done' | 'uploading' | 'removed';
export interface HttpRequestHeader {
    [key: string]: string;
}
export interface File {
    uid: number;
    size: number;
    name: string;
    lastModifiedDate?: Date;
    url?: string;
    status?: UploadFileStatus;
    percent?: number;
    thumbUrl?: string;
    originFileObj?: File;
}
export interface UploadChangeParam {
    file: File;
    fileList: Array<File>;
    event?: {
        percent: number;
    };
}
export interface UploadProps {
    type?: 'drag' | 'select';
    name?: string;
    defaultFileList?: Array<File>;
    fileList?: Array<File>;
    action: string;
    data?: Object | ((file: File) => any);
    headers?: HttpRequestHeader;
    showUploadList?: boolean;
    multiple?: boolean;
    accept?: string;
    beforeUpload?: (file: File) => boolean | PromiseLike<any>;
    onChange?: (info: UploadChangeParam) => void;
    listType?: 'text' | 'picture' | 'picture-card';
    className?: string;
    onPreview?: (file: File) => void;
    onRemove?: (file: File) => void;
    supportServerRender?: boolean;
    style?: React.CSSProperties;
    disabled?: boolean;
    prefixCls?: string;
}
export interface UploadListProps {
    listType?: 'text' | 'picture' | 'picture-card';
    onPreview?: (file: File) => void;
    onRemove?: (file: File) => void;
    items?: Array<File>;
    progressAttr?: Object;
    prefixCls?: string;
}

==> antd-2.7.1.jar: META-INF/resources/webjars/antd/2.7.1/lib/upload/interface.d.ts <==
/// <reference types="react" />
import React from 'react';
export declare type UploadFileStatus = 'error' | 'success' | 'done' | 'uploading' | 'removed';
export interface HttpRequestHeader {
    [key: string]: string;
}
export interface File {
    uid: number;
    size: number;
    name: string;
    lastModifiedDate?: Date;
    url?: string;
    status?: UploadFileStatus;
    percent?: number;
    thumbUrl?: string;
    originFileObj?: File;
}
export interface UploadChangeParam {
    file: File;
    fileList: Array<File>;
    event?: {
        percent: number;
    };
}
export interface ShowUploadListInterface {
    showRemoveIcon?: boolean;
    showPreviewIcon?: boolean;
}
export interface UploadProps {
    type?: 'drag' | 'select';
    name?: string;
    defaultFileList?: Array<File>;
    fileList?: Array<File>;
    action: string;
    data?: Object | ((file: File) => any);
    headers?: HttpRequestHeader;
    showUploadList?: boolean | ShowUploadListInterface;
    multiple?: boolean;
    accept?: string;
    beforeUpload?: (file: File) => boolean | PromiseLike<any>;
    onChange?: (info: UploadChangeParam) => void;
    listType?: 'text' | 'picture' | 'picture-card';
    className?: string;
    onPreview?: (file: File) => void;
    onRemove?: (file: File) => void | boolean;
    supportServerRender?: boolean;
    style?: React.CSSProperties;
    disabled?: boolean;
    prefixCls?: string;
}
export interface UploadListProps {
    listType?: 'text' | 'picture' | 'picture-card';
    onPreview?: (file: File) => void;
    onRemove?: (file: File) => void | boolean;
    items?: Array<File>;
    progressAttr?: Object;
    prefixCls?: string;
    showRemoveIcon?: boolean;
    showPreviewIcon?: boolean;
}
